@@ -1,7 +1,6 @@
+import urllib.request
 
 import typer
-import os
-print(os.getcwd())
 from rich import print
 
 from handlers.database_handler import SqliteHandler
@@ -11,7 +10,6 @@ app = typer.Typer()
 db_handler = SqliteHandler("local_app.db")
 
 
-@app.command()
 def input_rss(rss_link: str):
     """
     input-rss [rss_link] | input rss into the database
@@ -65,6 +63,7 @@ def get_news(limit: int = typer.Argument(10)):
     feed_handler: FeedHandler = FeedHandler(feeds[feed_index - 1][1], limit_page=limit)
     feed_handler.get_news()
 
+
 @app.command()
 def get_trends():
     """
@@ -91,6 +90,15 @@ def get_trends():
             return
 
 
+@app.command()
+def my_ip():
+    """
+    Get your ip
+    """
+    my_ip_address = urllib.request.urlopen('https://ident.me').read().decode('utf8')
+    print('Here is your ip address:', my_ip_address)
+
+
 def main():
     app()
 
